==> ScriptDeploy-0.1.tar: ScriptDeploy/method.uninstall.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/ScriptDeploy/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

/*
    For separated methods, you'll always want to start with the following
    line which check to make sure that method was called from the module
    API, and that everything's safe to continue:
*/ 
if (!isset($gCms)) exit;

	$db =& $gCms->GetDb();
//	
	// remove the database table
	$dict = NewDataDictionary( $db );
	$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_ScriptDeploy_scriptNames" );
	$dict->ExecuteSQLArray($sqlarray);
	
	$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_ScriptDeploy_scriptOptions" );
	$dict->ExecuteSQLArray($sqlarray);
	
	$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_ScriptDeploy_scriptParts" );
	$dict->ExecuteSQLArray($sqlarray);
	
	$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_ScriptDeploy_Group" );
	$dict->ExecuteSQLArray($sqlarray);	
	
	$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_ScriptDeploy_GroupAssignMent" );
	$dict->ExecuteSQLArray($sqlarray);	
	
	
	// remove the sequence
	// $db->DropSequence( cms_db_prefix()."module_rate_this_seq" );
//	
//	
//	
//	// remove the preferences
//	$this->RemovePreference("bookie");

$this->RemovePreference();
//	
//	// Remove all event handlers
//	$this->RemoveEventHandler('FrontEndUsers','OnCreateUser');
//	$this->RemoveEventHandler('FrontEndUsers','OnDeleteUser');
//	$this->RemoveEventHandler('FrontEndUsers','OnUpdateUser');
//	$this->RemoveEventHandler('FrontEndUsers','OnExpireUser');
//	$this->RemoveEventHandler('FrontEndUsers','OnLogin');
//	$this->RemoveEventHandler('FrontEndUsers','OnLogout');
//	
	// put mention into the admin log
	$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('uninstalled'));

?>

==> ScriptDeploy-0.3.tar: ScriptDeploy/method.uninstall.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/ScriptDeploy/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

/*
    For separated methods, you'll always want to start with the following
    line which check to make sure that method was called from the module
    API, and that everything's safe to continue:
*/ 
if (!isset($gCms)) exit;

	$db =& $gCms->GetDb();
//	
	// remove the database table
	$dict = NewDataDictionary( $db );
	$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_scriptdeploy_scriptnames" );
	$dict->ExecuteSQLArray($sqlarray);
	
	$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_scriptdeploy_scriptoptions" );
	$dict->ExecuteSQLArray($sqlarray);
	
	$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_scriptdeploy_scriptparts" );
	$dict->ExecuteSQLArray($sqlarray);
	
	$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_scriptdeploy_group" );
	$dict->ExecuteSQLArray($sqlarray);	
	
	$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_scriptdeploy_groupassignment" );
	$dict->ExecuteSQLArray($sqlarray);	
	
	
	// remove the sequence
	// $db->DropSequence( cms_db_prefix()."module_rate_this_seq" );
//	
//	
//	
//	// remove the preferences
//	$this->RemovePreference("bookie");

$this->RemovePreference();
//	
//	// Remove all event handlers
//	$this->RemoveEventHandler('FrontEndUsers','OnCreateUser');
//	$this->RemoveEventHandler('FrontEndUsers','OnDeleteUser');
//	$this->RemoveEventHandler('FrontEndUsers','OnUpdateUser');
//	$this->RemoveEventHandler('FrontEndUsers','OnExpireUser');
//	$this->RemoveEventHandler('FrontEndUsers','OnLogin');
//	$this->RemoveEventHandler('FrontEndUsers','OnLogout');
//	
	// put mention into the admin log
	$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('uninstalled'));

?>
